@@ -12,7 +12,7 @@ from pyrogram import Client
 from . import generals
 from .cog import Cog
 from .objects import Message, ChatActions, UserProfilePicture, CallbackQuery, Command, ChatPermission, \
-    PromotePermission, PreCheckOutQuery
+    PromotePermission, PreCheckOutQuery, Chat
 
 
 class CallbackError(Exception):
@@ -82,9 +82,31 @@ class Bot:
     # <---- custom API actions start ----> #
 
     async def delete_message(self, chat_id, message_id, revoke=True):
+        """
+        Delete message in chat_id with id of message_id
+
+        Parameters
+        -----------
+        chat_id: :class:`int`
+            The chat id where need delete message
+        message_id: :class:`int`
+            The uid of message who need delete
+        """
         return await self.pyrogram.delete_messages(chat_id, message_id, revoke)
 
     async def send_photo(self, chat_id: int, photo: str, **kwargs):
+        """
+        Send photo in chat with chat_id
+
+        Parameters
+        -----------
+        chat_id: :class:`int`
+            The chat id where need send photo
+        photo: :class:`str`
+            The file_id of file
+        **kwargs:
+            another parameters, see `Telegramm API <https://core.telegram.org/bots/api#sendphoto>`_
+        """
         dic = {
             'chat_id': chat_id,
             'photo': photo
@@ -96,6 +118,18 @@ class Bot:
         return await self._tg_request('sendPhoto', True, **dic)
 
     async def send_sticker(self, chat_id, sticker, **kwargs):
+        """
+        Send stricker in chat with chat_id
+
+        Parameters
+        -----------
+        chat_id: :class:`int`
+            The chat id where need send sticker
+        sticker: :class:`str`
+            The file_id of sticker
+        **kwargs:
+            another parameters, see `Telegramm API <https://core.telegram.org/bots/api#sendsticker>`_
+        """
         dic = {
             'chat_id': chat_id,
             'sticker': sticker
@@ -104,9 +138,31 @@ class Bot:
         return await self._tg_request('sendSticker', True, **dic)
 
     async def send_chat_action(self, chat_id, chat_action: ChatActions):
+        """
+        Send bot action in chat with chat_id
+
+        Parameters
+        -----------
+        chat_id: :class:`int`
+            The chat id where need send action
+        chat_action: :class:`.ChatActions`
+            The chat action that will be display in chat. see `Telegramm API <https://core.telegram.org/bots/api#sendchataction>`_
+        """
         return await self._tg_request('sendChatAction', True, **{'chat_id': chat_id, 'action': chat_action.value})
 
     async def send_dice(self, chat_id, emoji, **kwargs):
+        """
+        Send dice in chat with chat_id
+
+        Parameters
+        -----------
+        chat_id: :class:`int`
+            The chat id where need send dice
+        emoji: :class:`str`
+            The emoji that need send
+        **kwargs:
+            see `Telegramm API <https://core.telegram.org/bots/api#senddice>`_
+        """
         dic = {
             'chat_id': chat_id,
             'emoji': emoji
@@ -119,6 +175,28 @@ class Bot:
         return rs.get('result').get('dice').get('value')
 
     async def send_invoice(self,chat_id:int,title:str,description:str,payload:str,provider_token:str,prices,currency='RUB',**kwargs):
+        """
+        Send invoice (payment) message in chat
+
+        Parameters
+        -----------
+        chat_id: :class:`int`
+            The chat id where need send photo
+        title: :class:`str`
+            The title of invoice
+        description: :class:`str`
+            The description of invoice
+        payload: :class:`str`
+            The some information who will be transfer in handler, who handler user's pay
+        provider_token: :class:`str`
+            The payment token, see https://core.telegram.org/bots/payments
+        prices: :class:`int`
+            The price
+        currency: :class:`str`
+            The code of price, eg. 'RUB','USD'
+        **kwargs:
+            see `Telegramm API <https://core.telegram.org/bots/api#sendinvoice>`_
+        """
         dic = {
             'chat_id':chat_id,
             'title':title,
@@ -135,6 +213,15 @@ class Bot:
                 raise ToMenyRequests(message=None, *rs)
         return rs
 
+    async def get_chat(self,chat_id:int):
+        rs = await self._tg_request('getChat',True,**{'chat_id':chat_id})
+        if not rs.get('ok'):
+            if rs.get('error_code') == 429:
+                raise ToMenyRequests(rs.get('description'), rs)
+            else:
+                raise TgAPIException(rs)
+        return Chat(rs.get('result'))
+
     async def restrict_chat_member(self, chat_id: int, user_id: int, permission: ChatPermission, until_date=None):
         dic = {
             'chat_id': chat_id,
@@ -209,8 +296,8 @@ class Bot:
     async def kick_chat_member(self, chat_id: int, user_id: int):
         return await self._tg_request('kickChatMember', True, **{'chat_id': chat_id, 'user_id': user_id})
 
-    async def unban_chat_member(self, chat_id: int, user_id: int):
-        return await self._tg_request('unbanChatMember', True, **{'chat_id': chat_id, 'user_id': user_id})
+    async def unban_chat_member(self, chat_id: int, user_id: int,only_if_banned:bool = False):
+        return await self._tg_request('unbanChatMember', True, **{'chat_id': chat_id, 'user_id': user_id, 'only_if_banned':only_if_banned})
 
     async def answer_callback_query(self, id: int, text: str, show_alert=False):
         dic = {
@@ -242,6 +329,16 @@ class Bot:
         rs = await self._tg_request('sendMessage', True, **dic)
         return await self.prefe_incomming_message(rs)
 
+    async def get_file(self,file_id:str):
+        dic = {'file_id':file_id}
+        rs = await self._tg_request('getFile',True,**dic)
+        if not rs.get('ok'):
+            if rs.get('error_code') == 429:
+                raise ToMenyRequests(rs.get('description'), rs)
+            else:
+                raise TgAPIException(rs)
+        return rs
+
     async def prefe_incomming_message(self, message):
         if not message.get('ok'):
             for _m in self.listeners_handle.get('on_invoke_command_error'):
