@@ -191,6 +191,14 @@ class Message:
         except Exception:
             self.entities = []
 
+    async def get_photos(self):
+        if not self.photo:
+            return None
+        rs = (await self.bot.get_file(self.photo.file_id)).get('result')
+        return rs.get('file_id')
+
+
+
     def get_event_user(self):
         if self.new_chat_member or self.new_chat_participant:
             return self.new_chat_member or self.new_chat_participant
@@ -200,6 +208,13 @@ class Message:
             return self.user
 
     async def delete_message(self):
+        """
+        Delete this message in chat
+
+        Parameters
+        -----------
+        None
+        """
         return await self.bot.delete_message(self.chat.id, self.message_id)
 
     def get_text(self) -> str:
@@ -361,6 +376,9 @@ class Chat:
             self.chatObj = UserChat(payload)
         elif type == 'group':
             self.chatObj = GroupChat(payload)
+        self.invite_link = payload.get('invite_link') if 'invite_link' in payload else None
+        self.permissions = ChatPermission(payload.get('permissions')) if 'permissions' in payload else None
+        self.join_to_send_messages = payload.get('join_to_send_messages') if 'join_to_send_messages' in payload else False
 
 
 class ChatActions(Enum):
